xirr_flutter library

Classes

Transaction
Represents a transaction for the purposes of computing the irregular rate of return.
XirrFlutter
Calculates the irregular rate of return on a series of transactions. The irregular rate of return is the constant rate for which, if the transactions had been applied to an investment with that rate, the same resulting returns would be realized.

Extensions

Ex on double