Transaction class
Represents a transaction for the purposes of computing the irregular rate of return.
Note that negative amounts represent deposits into the investment (and so withdrawals from your cash). Positive amounts represent withdrawals from the investment (deposits into cash). Zero amounts are allowed in case your investment is now worthless. @see Xirr
Constructors
- Transaction(double amount, DateTime when)
- Construct a Transaction instance with the given amount at the given day. @param amount the amount transferred @param when the day the transaction took place
- Transaction.withStringDate(double amount, String when)
- Construct a Transaction instance with the given amount at the given day. @param amount the amount transferred @param when the day the transaction took place
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited